# Honkai Star Rail - `starrail`

**Note: This package is currently under development.**

Honkai: Star Rail Automation Package (auto-resource grinder).

## Installation / Setup
The install the `starrail` package, run:
```shell
pip install starrail
```
OR
```shell
git clone https://github.com/ReZeroE/StarRail.git
cd StarRail/
pip install .
```
